# -*- coding: utf-8 -*-

class AzureObjectTypeEnum(object):

    """Implementation of the 'azureObjectType' enum.

    TODO: type enum description here.

    Attributes:
        KSUBSCRIPTION: TODO: type description here.
        KRESOURCEGROUP: TODO: type description here.
        KVIRTUALMACHINE: TODO: type description here.
        KSTORAGEACCOUNT: TODO: type description here.
        KSTORAGEKEY: TODO: type description here.
        KSTORAGECONTAINER: TODO: type description here.
        KSTORAGEBLOB: TODO: type description here.
        KNETWORKSECURITYGROUP: TODO: type description here.
        KVIRTUALNETWORK: TODO: type description here.
        KSUBNET: TODO: type description here.
        KCOMPUTEOPTIONS: TODO: type description here.
        KSNAPSHOTMANAGERPERMIT: TODO: type description here.
        KTAG: TODO: type description here.
        KAVAILABILITYSET: TODO: type description here.

    """

    KSUBSCRIPTION = 'kSubscription'

    KRESOURCEGROUP = 'kResourceGroup'

    KVIRTUALMACHINE = 'kVirtualMachine'

    KSTORAGEACCOUNT = 'kStorageAccount'

    KSTORAGEKEY = 'kStorageKey'

    KSTORAGECONTAINER = 'kStorageContainer'

    KSTORAGEBLOB = 'kStorageBlob'

    KNETWORKSECURITYGROUP = 'kNetworkSecurityGroup'

    KVIRTUALNETWORK = 'kVirtualNetwork'

    KSUBNET = 'kSubnet'

    KCOMPUTEOPTIONS = 'kComputeOptions'

    KSNAPSHOTMANAGERPERMIT = 'kSnapshotManagerPermit'

    KTAG = 'kTag'

    KAVAILABILITYSET = 'kAvailabilitySet'
